<?php require_once __DIR__ . '/../includes/bootstrap.php'; require_login();
$id = (int)($_GET['id'] ?? 0);
$stmt = db()->prepare("DELETE FROM attendance WHERE id=?");
$stmt->execute([$id]);
audit_log('delete', 'attendance', $id, 'Eliminación asistencia');
set_flash('success','Marcación eliminada.');
redirect('attendance/index.php');
