<?php require_once __DIR__ . '/../includes/bootstrap.php';
require_admin();
$id = (int)($_GET['id'] ?? 0);
$stmt = db()->prepare("DELETE FROM employees WHERE id=?");
$stmt->execute([$id]);
audit_log('delete', 'employees', $id, 'Eliminación empleado');
set_flash('success','Empleado eliminado.');
redirect('employees/index.php');
