<?php include __DIR__ . '/../includes/header.php'; ensure_can_manage_master_data(); ?>
<div class="table-wrap" style="max-width:760px">
  <h4 class="mb-3">Candidato</h4>
  <form method="post" action="<?= e(base_url('recruitment/candidate_create.php')) ?>">
    <?php if (!empty($item['id'])): ?><input type="hidden" name="id" value="<?= (int)$item['id'] ?>"><?php endif; ?>
    <div class="mb-3"><label class="form-label">Nombre completo</label><input type="text" name="full_name" class="form-control" value="<?= e($item['full_name'] ?? '') ?>"></div><div class="mb-3"><label class="form-label">Cédula</label><input type="text" name="document_number" class="form-control" value="<?= e($item['document_number'] ?? '') ?>"></div><div class="mb-3"><label class="form-label">Teléfono</label><input type="text" name="phone" class="form-control" value="<?= e($item['phone'] ?? '') ?>"></div><div class="mb-3"><label class="form-label">Email</label><input type="email" name="email" class="form-control" value="<?= e($item['email'] ?? '') ?>"></div><div class="mb-3"><label class="form-label">Observación</label><textarea name="notes" class="form-control" rows="3"><?= e($item['notes'] ?? '') ?></textarea></div>
    <div class="d-flex gap-2"><button class="btn btn-primary">Guardar</button><a class="btn btn-outline-secondary" href="<?= e(base_url('recruitment/index.php')) ?>">Volver</a></div>
  </form>
</div>
<?php include __DIR__ . '/../includes/footer.php'; ?>