<?php
define('APP_NAME', 'HM ERP RRHH v5');
define('BASE_URL', ''); // Ej: /erp si lo subís en subcarpeta. Si está en dominio/raíz dejar ''
define('DB_HOST', 'localhost');
define('DB_NAME', 'tu_base');
define('DB_USER', 'tu_usuario');
define('DB_PASS', 'tu_clave');
define('TIMEZONE', 'America/Asuncion');
