<?php
function current_user() { return $_SESSION['user'] ?? null; }
function require_login() { if (empty($_SESSION['user'])) { redirect('login.php'); } }
function require_admin() { require_login(); if (!role_is('admin')) { set_flash('danger', 'No tenés permiso para acceder a esta sección.'); redirect('dashboard.php'); } }
function require_roles(array $roles) { ensure_roles($roles); }
function login_user($user) { $_SESSION['user'] = ['id'=>$user['id'],'name'=>$user['full_name'],'email'=>$user['email'],'role'=>$user['role']]; }
function logout_user() { unset($_SESSION['user']); session_destroy(); }
