<?php
session_start();

if (!file_exists(__DIR__ . '/../config/config.php')) {
    die('Falta config/config.php. Copiá config.sample.php a config.php y completá los datos.');
}

require_once __DIR__ . '/../config/config.php';
date_default_timezone_set(defined('TIMEZONE') ? TIMEZONE : 'America/Asuncion');

require_once __DIR__ . '/db.php';
require_once __DIR__ . '/functions.php';
require_once __DIR__ . '/auth.php';
