<?php
require_once __DIR__ . '/../includes/bootstrap.php';
require_login();
ensure_can_manage_payroll();
$id = (int)($_GET['id'] ?? 0);
$period = generate_or_refresh_payroll_period($id, false);
if (!$period) {
    set_flash('danger', 'Período no encontrado.');
    redirect('payroll/index.php');
}
audit_log('generate', 'payroll_periods', $id, 'Generación/regeneración de nómina con adelantos');
set_flash('success', 'Nómina generada o actualizada con adelantos del período.');
redirect('payroll/view.php?id=' . $id);
