<?php require_once __DIR__ . '/../includes/bootstrap.php'; require_admin();
$id = (int)($_GET['id'] ?? 0);
if ($id === (int) current_user()['id']) {
  set_flash('danger', 'No podés eliminar tu propio usuario.');
  redirect('users/index.php');
}
$stmt = db()->prepare("DELETE FROM users WHERE id=?");
$stmt->execute([$id]);
audit_log('delete', 'users', $id, 'Eliminación usuario');
set_flash('success','Usuario eliminado.');
redirect('users/index.php');
