<?php
require_once __DIR__ . '/../includes/bootstrap.php'; require_login(); ensure_can_manage_master_data();
$id = (int)($_GET['id'] ?? 0);
$stmt = db()->prepare("DELETE FROM recruitment_candidates WHERE id=?"); $stmt->execute([$id]);
audit_log('delete','recruitment_candidates',$id,'Candidato eliminado');
set_flash('success','Candidato eliminado.'); redirect('recruitment/index.php');
